==> react-native-cometchat-calling-component-3.0.1.tgz: package/util/Constants.js <==
export const SCREEN_SHARING_STARTED = "SCREEN_SHARING_STARTED";
export const SCREEN_SHARING_STOPPED = "SCREEN_SHARING_STOPPED";

// this is passed in jitsi,eetjs.init
export const initOptions = {
  disableAudioLevels: false,
  desktopSharingChromeExtId: "mbocklcggfhnbahlnepmldehdhpjfcjp",
  desktopSharingChromeDisabled: false,
  desktopSharingChromeSources: ["screen", "window"],
  desktopSharingChromeMinExtVersion: "0.1",
  desktopSharingFirefoxDisabled: false,
  enableTalkWhileMuted: true,
  enableNoisyMicDetection: true,
  enableLayerSuspension: true,
  channelLastN,
};

//this is passed in connection.initJitsiConference(new backend config)
export const confOptions = {
  openBridgeChannel: "websocket",
  enableNoisyMicDetection: true,
  channelLastN: 10,
  openBridgeChannel: "websocket",
  websocketKeepAlive: -1,
  testing: {
    octo: { probability: 1 },
  },
  e2eping: { pingInterval: -1 },
  deploymentInfo: {
    userRegion: "eu-west-1",
  },
  enableTalkWhileMuted: true,
};
// (old backend config)
// const confOptions = {
//   openBridgeChannel: true,
//   enableNoisyMicDetection: true,
//   channelLastN,
//   enableLayerSuspension: true,
//   enableTalkWhileMuted: true,
// };

// ui modes 
export const singleMode="SINGLE"
export const spotlightMode="SPOTLIGHT"

//this is passed in JitsiMeetJS.JitsiConnection(new backend)
export const  options = {
hosts: {
    domain: "rtcb-test.cometchat.io",
    focus: "focus.rtcb-test.cometchat.io",
    muc: "conference.rtcb-test.cometchat.io",
},
websocket: "wss://xmpp.rtcb-test.cometchat.io/xmpp-websocket",
bosh: "https://xmpp.rtcb-test.cometchat.io/http-bind",
};

    //(old backend)
     // var options = {
    //   hosts: {
    //     domain: this.getDomain(),
    //     muc: this.getMUC(),
    //   },
    //   enableNoisyMicDetection: true,
    //   bosh: this.getBosh(),
    //   clientNode: "http://jitsi.org/jitsimeet",
    //   channelLastN,
    //   enableLayerSuspension: true,
    //   enableTalkWhileMuted: true,
    // };

       // var options = {
    //   hosts: {
    //     domain: "rtcb-test.cometchat.io",
    //     muc: "muc.rtcb-test.cometchat.io",
    //   },
    //   enableNoisyMicDetection: true,
    //   bosh: "https://xmpp.rtcb-test.cometchat.io/http-bind",
    //   clientNode: "http://jitsi.org/jitsimeet",
    //   channelLastN,
    //   enableLayerSuspension: true,
    //   enableTalkWhileMuted: true,
    // };

==> react-native-cometchat-calling-component-3.0.3.tgz: package/util/Constants.js <==
export const SCREEN_SHARING_STARTED = "SCREEN_SHARING_STARTED";
export const SCREEN_SHARING_STOPPED = "SCREEN_SHARING_STOPPED";

// this is passed in jitsi,eetjs.init
// export const initOptions = {
//   disableAudioLevels: false,
//   desktopSharingChromeExtId: "mbocklcggfhnbahlnepmldehdhpjfcjp",
//   desktopSharingChromeDisabled: false,
//   desktopSharingChromeSources: ["screen", "window"],
//   desktopSharingChromeMinExtVersion: "0.1",
//   desktopSharingFirefoxDisabled: false,
//   enableTalkWhileMuted: true,
//   enableNoisyMicDetection: true,
//   enableLayerSuspension: true,
//   channelLastN,
// };

//this is passed in connection.initJitsiConference(new backend config)
export const confOptions = {
  openBridgeChannel: "websocket",
  enableNoisyMicDetection: true,
  channelLastN: 10,
  openBridgeChannel: "websocket",
  websocketKeepAlive: -1,
  testing: {
    octo: { probability: 1 },
  },
  e2eping: { pingInterval: -1 },
  deploymentInfo: {
    userRegion: "eu-west-1",
  },
  enableTalkWhileMuted: true,
};
// (old backend config)
// const confOptions = {
//   openBridgeChannel: true,
//   enableNoisyMicDetection: true,
//   channelLastN,
//   enableLayerSuspension: true,
//   enableTalkWhileMuted: true,
// };

// ui modes 
export const singleMode="SINGLE"
export const spotlightMode="SPOTLIGHT"

//this is passed in JitsiMeetJS.JitsiConnection(new backend)
export const  options = {
hosts: {
    domain: "rtcb-test.cometchat.io",
    focus: "focus.rtcb-test.cometchat.io",
    muc: "conference.rtcb-test.cometchat.io",
},
websocket: "wss://xmpp.rtcb-test.cometchat.io/xmpp-websocket",
bosh: "https://xmpp.rtcb-test.cometchat.io/http-bind",
};

    //(old backend)
     // var options = {
    //   hosts: {
    //     domain: this.getDomain(),
    //     muc: this.getMUC(),
    //   },
    //   enableNoisyMicDetection: true,
    //   bosh: this.getBosh(),
    //   clientNode: "http://jitsi.org/jitsimeet",
    //   channelLastN,
    //   enableLayerSuspension: true,
    //   enableTalkWhileMuted: true,
    // };

       // var options = {
    //   hosts: {
    //     domain: "rtcb-test.cometchat.io",
    //     muc: "muc.rtcb-test.cometchat.io",
    //   },
    //   enableNoisyMicDetection: true,
    //   bosh: "https://xmpp.rtcb-test.cometchat.io/http-bind",
    //   clientNode: "http://jitsi.org/jitsimeet",
    //   channelLastN,
    //   enableLayerSuspension: true,
    //   enableTalkWhileMuted: true,
    // };
